@@ -1,4 +1,4 @@
-#ident "$Id: faxlib.c,v 4.51 2001/10/01 18:47:18 gert Exp $ Copyright (c) Gert Doering"
+#ident "$Id: faxlib.c,v 4.54 2002/11/04 22:54:37 gert Exp $ Copyright (c) Gert Doering"
 
 /* faxlib.c
  *
@@ -42,18 +42,24 @@ int	modem_quirks = 0;		/* modem specials */
  * handle all the various class 2 / class 2.0 status responses
  */
 
-/* copy fax station id, removing quote characters (dangerous for shell!) */
+/* copy fax station id, removing quote characters (dangerous for shell!)
+ * and leading/trailing whitespace
+ */
 static void fwf_copy_remote_id _P1( (id), char * id )
 {
 int w = 0;
 
-    while ( isspace(*id) ) id++;	/* skip leading whitespace */
+    while ( isspace(*id) || *id == '"' ) id++;	/* skip leading whitespace */
 
     while ( *id && w < sizeof(fax_remote_id)-1 )
     {
         if ( *id != '"' && *id != '\'' ) fax_remote_id[w++] = *id;
         id++;
     }
+
+    /* remove trailing whitespace */
+    while ( w>0 && isspace(fax_remote_id[w-1]) ) w--;
+
     fax_remote_id[w]=0;
 }
 
@@ -607,12 +613,16 @@ int mdm_identify _P1( (fd), int fd )
 	    break;
 	  case 1281:
 	  case 1291:
-	  case 1292:
 	  case 1293:
 	    lprintf( L_MESG, "ZyXEL Omni.NET detected" );
 	    modem_type=Mt_data;				/* has no fax mode */
 	    mis = mdm_get_idstring( "ATI1", 1, fd );
 	    break;
+	  case 1292:
+	    lprintf( L_MESG, "ZyXEL Omni.NET LCD+M detected" );
+	    modem_type=Mt_class2;			/* rockwell based */
+	    mis = mdm_get_idstring( "ATI1", 1, fd );
+	    break;
 	  case 1500:
 	  case 1501:
 	    lprintf( L_MESG, "ZyXEL Omni 56K (Plus) detected" );
