@@ -1,4 +1,4 @@
-#ident "$Id: login.c,v 4.12 2001/03/13 20:32:40 gert Exp $ Copyright (C) 1993 Gert Doering"
+#ident "$Id: login.c,v 4.18 2002/03/12 11:12:23 gert Exp $ Copyright (C) 1993 Gert Doering"
 
 
 /* login.c
@@ -17,6 +17,7 @@
 #endif
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <fcntl.h>
 
 /* NeXTStep/86 has some byte order problems (Christian Starkjohann) */
 #if defined(NeXT) && defined(__LITTLE_ENDIAN__) && !defined(NEXTSGTTY)
@@ -107,7 +108,7 @@ void login_dispatch _P3( (user, is_callback, cfg_file ),
 			 char * user, boolean is_callback, char * cfg_file )
 {
 #define MAX_LOGIN_ARGS 9
-    char * argv[MAX_LOGIN_ARGS+1];
+    char * argv[MAX_LOGIN_ARGS+2];	/* name + args + NULL */
     int	argc = 0;
     char * cmd = NULL;
     int i;
@@ -146,7 +147,7 @@ void login_dispatch _P3( (user, is_callback, cfg_file ),
     if ( st.st_uid != 0 || ( ( st.st_mode & 0077 ) != 0 ) )
     {
 	errno=EINVAL;
-	lprintf( L_FATAL, "login: '%s' must be root/0600", cfg_file );
+	lprintf( L_FATAL, "login: '%s' ignored, wrong permissions. Must be owned by 'root' and have mode '0600'", cfg_file );
 	goto fallthrough;
     }
 
@@ -286,7 +287,7 @@ void login_dispatch _P3( (user, is_callback, cfg_file ),
 	    
 	    argc = 1;
 	    p = strtok( NULL, " \t" );
-	    while ( argc < MAX_LOGIN_ARGS && p != NULL )
+	    while ( argc <= MAX_LOGIN_ARGS && p != NULL )
 	    {
 		if ( strcmp( p, "@" ) == 0 )		/* user name */
 		{
@@ -310,7 +311,7 @@ void login_dispatch _P3( (user, is_callback, cfg_file ),
 	    }
 
 	    if ( p != NULL )			/* arguments left? */
-		lprintf( L_WARN, "login.config: max. %d command line arguments possible", MAX_LOGIN_ARGS );
+		lprintf( L_WARN, "login.config: max. %d command line arguments possible, truncated at: '%s'", MAX_LOGIN_ARGS, p);
 
 	    break;
 	}		/* end if (matching line found) */
@@ -343,17 +344,23 @@ fallthrough:
     for ( i=0; i<argc; i++) { lputs( L_NOISE, argv[i] ); 
 			      lputs( L_NOISE, (i<argc-1)?" ":"'" ); }
 
+    /* set a couple of environment variables (mainly useful for "special"
+     * logins, like Fido and AutoPPP, because /bin/login reconstructs its
+     * environment from scratch) - not general enough, though.
+     */
+    setup_environment();
+
     /* audit record */
     lprintf( L_AUDIT, 
        "data dev=%s, pid=%d, caller='%s', conn='%s', name='%s', cmd='%s', user='%s'",
 	Device, getpid(), CallerId, Connect, CallName,
 	cmd, user );
 
-    /* set a couple of environment variables (mainly useful for "special"
-     * logins, like Fido and AutoPPP, because /bin/login reconstructs its
-     * environment from scratch) - not general enough, though.
+    /* make sure close-on-exec bit is unset
+     * (BUG in FreeBSD 4.1.1 syslog() - sets c-o-e on FD 0 !!!
      */
-    setup_environment();
+    if ( fcntl(0, F_GETFD, 0 ) & 1 ) 
+	lprintf( L_WARN, "WARNING: close-on-exec bit set on FD 0 - OS BUG?" );
 
     /* execute login */
     execv( cmd, argv );
@@ -366,8 +373,12 @@ fallthrough:
 
 void setup_environment _P0(void)
 {
-    set_env_var( "CALLER_ID", CallerId );
-    set_env_var( "CALLED_ID", CalledNr );
+    if ( *CallerId )
+	set_env_var( "CALLER_ID", CallerId );
+    if ( *CallName )
+	set_env_var( "CALLER_NAME", CallName );
+    if ( *CalledNr )
+	set_env_var( "CALLED_ID", CalledNr );
     set_env_var( "CONNECT", Connect );
     set_env_var( "DEVICE", Device );
 }
