@@ -5,7 +5,7 @@
  * follow the IS-101 interim standard for voice modems. Since the commands
  * are set in the modem structure, it should be quite generic.
  *
- * $Id: IS_101.c,v 1.14 2001/08/06 17:46:18 marcs Exp $
+ * $Id: IS_101.c,v 1.16 2002/12/13 09:51:19 gert Exp $
  *
  */
 
@@ -145,6 +145,8 @@ int IS_101_dial(char *number)
 
 int IS_101_handle_dle(char data)
      {
+     static int dtmf_shielding = 0;	/* flag variable for shielded DTMF */
+     static int dtmf_count = 0;		/* flag variable for shielded DTMF */
 
      switch (data)
           {
@@ -186,8 +188,10 @@ int IS_101_handle_dle(char data)
            */
 
           case '/':
-               lprintf(L_WARN, "%s: Start of DTMF shielding received",
-                program_name);
+               lprintf(L_NOISE, "%s: Start of DTMF shielding received",
+                       program_name);
+               dtmf_shielding = 1;
+	       dtmf_count = 0;
                return(OK);
 
           /*
@@ -195,8 +199,9 @@ int IS_101_handle_dle(char data)
            */
 
           case '~':
-               lprintf(L_WARN, "%s: End of DTMF shielding received",
-                program_name);
+               lprintf(L_NOISE, "%s: End of DTMF shielding received",
+                       program_name);
+               dtmf_shielding = 0;
                return(OK);
 
           /*
@@ -219,16 +224,22 @@ int IS_101_handle_dle(char data)
           case 'B':
           case 'C':
           case 'D':
-               {
-               event_type *event;
-               event_data dtmf;
+               /* IS-101 DTMF sequence: <DLE></><DLE><value>...<DLE><~>
+                *     <DLE><value> is repeated every 70 ms during tone
+		* -> use hearing_dtmf flag to generate only one event
+		*/
+	       dtmf_count++;
+               if ( !dtmf_shielding || dtmf_count <= 1 ) 
+	       {
+                    event_type *event;
+                    event_data dtmf;
 
-               event = create_event(RECEIVED_DTMF);
-               dtmf.c = data;
-               event->data = dtmf;
-               queue_event(event);
+                    event = create_event(RECEIVED_DTMF);
+                    dtmf.c = data;
+                    event->data = dtmf;
+                    queue_event(event);
+	       }
                return(OK);
-               }
 
           /*
            * Data or fax answer detected
